@@ -12,6 +12,14 @@ def process_args():
     parser = argparse.ArgumentParser(
         description="Manage AWS CodePipeline",
     )
+    parser.add_argument(
+        "--profile",
+        help="Name of the AWS profile to use",
+    )
+    parser.add_argument(
+        "--region",
+        help="Name of the AWS region to use",
+    )
     subparsers = parser.add_subparsers()
 
     watch = subparsers.add_parser("watch", help="watch pipeline activity")
@@ -74,7 +82,7 @@ def process_args():
     rollback.set_defaults(func=rollback_pipeline)
     args = vars(parser.parse_args())
     if "func" in args:
-        args["func"](session=boto3.session.Session(), **args)
+        args["func"](session=boto3.session.Session(profile_name=args['profile'], region_name=args['region']), **args)
     else:
         parser.print_help()
 
