@@ -49,14 +49,14 @@ class LogContextManager:
             self.status_cache[ctx_id] = self.status_manager.status_bar(
                 status_format="{status} [{commit_id}] - {commit_message}",
                 color=logger.color[0],
-                commit_id=commit_id[:8],
+                commit_id=(commit_id[:8] if commit_id else ""),
                 commit_message=commit_message_summary,
                 status=status,
                 leave=False,
             )
         else:
             self.status_cache[ctx_id].update(
-                commit_id=commit_id[:8],
+                commit_id=(commit_id[:8] if commit_id else ""),
                 commit_message=commit_message_summary,
                 status=status,
             )
