@@ -219,13 +219,14 @@ def rollback_pipeline(
             else:
                 primary_artifact = None
 
-            build = rerun_build(
-                session=session,
-                build_id=action["output"]["executionResult"]["externalExecutionId"],
-                input_artifact=primary_source,
-                output_artifact=primary_artifact,
-                dryrun=dryrun,
-            )
+            if "executionResult" in action["output"]:
+              build = rerun_build(
+                  session=session,
+                  build_id=action["output"]["executionResult"]["externalExecutionId"],
+                  input_artifact=primary_source,
+                  output_artifact=primary_artifact,
+                  dryrun=dryrun,
+              )
 
             if not dryrun and not no_wait:
                 logger = ctx_mgr.set_context(
